import {useLocation} from "react-router-dom";
import {SetStateAction, useEffect} from "react";

export function setCookie(name: string, value: any, expirationDate: Date) {
    let expires = "expires=" + expirationDate;
    document.cookie = `${name}=${value}; ${expires}`
}

export function getCookie(name: string | any[]) {

    const cDecoded = decodeURIComponent(document.cookie);
    const cArray = cDecoded.split("; ");
    let result = null;

    cArray.forEach(element => {

        if (element.indexOf(<string>name) == 0) {
            result = element.substring(name.length + 1)
        }
    })
    return result;
}

export function deleteJwtCookie() {
    document.cookie = `Jwt=; expires=Thu, 01 Jan 1970 00:00:00 UTC; path=/;`;
    console.log("deleted Cookie ")
}

export function checkJwtStatus(setIsLoggedIn: { (value: SetStateAction<boolean>): void; (arg0: boolean): void; }) {

    const location = useLocation();

    return useEffect(() => {
        console.log("check jwt-status")
        const jwtCookie = getCookie("Jwt");
        console.log("Jwt Cookie " + jwtCookie)

        if (!jwtCookie) {
            // Wenn der JWT-Cookie nicht vorhanden ist
            setIsLoggedIn(false);
            console.log("Jwt not there")
            return;
        }

        // Der JWT-Cookie ist vorhanden - Überprüfe die Gültigkeit
        // @ts-ignore
        const tokenParts = jwtCookie.split('.');

        if (tokenParts.length !== 3) {
            // Ungültiges JWT-Format (nicht genau 3 Teile)
            setIsLoggedIn(false);
            console.log("Jwt is not valid")
            return;
        }

        const payload = JSON.parse(atob(tokenParts[1]));
        const expirationTime = payload.exp*1000; //Umwandlung in Millisekunden
        console.log(expirationTime)
        console.log(Date.now())

        // Überprüfe das Ablaufdatum
        if (Date.now() > expirationTime) {
            // JWT ist abgelaufen
            setIsLoggedIn(false);
            console.log("Jwt is expired")
            return;
        }
        console.log("Token is there and valid")
        // JWT ist vorhanden und gültig
        setIsLoggedIn(true);
    }, [location.pathname]);

}
